@@ -395,7 +395,7 @@ less tests/filter.tgz:test.pem		# SSL related files git #15
 less tests/filter.tgz:test.bplist	# Apple binary property list, needs plistutil
 ~ <dict>
 ###    no test case for decoding gpg/pgp encrypted files git #12
-less tests/filter.tgz:test_mp3		# mp3 without mp3 extension, needs mediainfo|exiftools
+less tests/filter.tgz:test_mp3		# mp3 without mp3 extension, needs exiftool, not mediainfo
 ~ Title .* test
 less tests/filter.tgz:test_mp3:mp3	# mp3, needs id3v2
 ~ Title  : test .*
@@ -422,7 +422,7 @@ less tests/filter.tgz:test.pod:pod	# unmodified pod text, colorized, needs pod2t
 c =head1
 less tests/filter.tgz:test_plain:sh	# plain text, force color (shellscript)
 c test
-less tests/filter.tgz:index.rst		# Jupyter notebook to rst git #6, needs mdcat|pandoc
+less tests/filter.tgz:index.rst		# reStructuredText, needs mdcat
 c # test
 less tests/filter.tgz:test.json		# json, epub and ipynb also covered git #62 (fails if no syntax/json.vim), needs pandoc
 c false
@@ -440,7 +440,7 @@ c sub
 LESS= less $T/tests/a-r-R.pl		# name contains -r or -R git #78
 = sub test {}
 less $T/tests/test_zip:non-existent-file	# nonexisting file in a zip archive git issue #1
-= 
+~ 
 less $T/tests/test\ \;\'\"\[\(\{ok		# file name with chars such as ", ' ...
 = test
 less tests/special.tgz:test\ \;\'\"\[\(\{ok	# archive having a file with chars from [ ;"'] etc. in the name
